summaryrefslogtreecommitdiffstats
path: root/kmail/imapaccountbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/imapaccountbase.h')
-rw-r--r--kmail/imapaccountbase.h33
1 files changed, 17 insertions, 16 deletions
diff --git a/kmail/imapaccountbase.h b/kmail/imapaccountbase.h
index 0795eb2ab..eee46417d 100644
--- a/kmail/imapaccountbase.h
+++ b/kmail/imapaccountbase.h
@@ -58,8 +58,9 @@ namespace KMail {
class ImapAccountBase : public KMail::NetworkAccount {
Q_OBJECT
+ TQ_OBJECT
protected:
- ImapAccountBase( AccountManager * parent, const TQString & name, uint id );
+ ImapAccountBase( AccountManager * tqparent, const TQString & name, uint id );
public:
virtual ~ImapAccountBase();
@@ -141,13 +142,13 @@ namespace KMail {
struct jobData
{
// Needed by TQMap, don't use
- jobData() : url(TQString::null), parent(0), current(0), total(1), done(0), offset(0), progressItem(0),
+ jobData() : url(TQString()), tqparent(0), current(0), total(1), done(0), offset(0), progressItem(0),
onlySubscribed(false), quiet(false), cancellable(false) {}
// Real constructor
- jobData( const TQString& _url, KMFolder *_parent = 0,
+ jobData( const TQString& _url, KMFolder *_tqparent = 0,
int _total = 1, int _done = 0, bool _quiet = false,
bool _cancelable = false )
- : url(_url), parent(_parent), current(0), total(_total), done(_done), offset(0),
+ : url(_url), tqparent(_tqparent), current(0), total(_total), done(_done), offset(0),
progressItem(0), quiet(_quiet), cancellable(_cancelable) {}
TQString path;
@@ -156,7 +157,7 @@ namespace KMail {
TQByteArray data;
TQCString cdata;
TQStringList items;
- KMFolder *parent, *current;
+ KMFolder *tqparent, *current;
TQPtrList<KMMessage> msgList;
int total, done, offset;
KPIM::ProgressItem *progressItem;
@@ -173,7 +174,7 @@ namespace KMail {
/**
* Look for the jobData related to a given job. Compare with end()
*/
- JobIterator findJob( KIO::Job* job ) { return mapJobData.find( job ); }
+ JobIterator findJob( KIO::Job* job ) { return mapJobData.tqfind( job ); }
JobIterator jobsEnd() { return mapJobData.end(); }
/**
* Call this when a job is finished.
@@ -230,13 +231,13 @@ namespace KMail {
* Set the status on the server
* Emits imapStatusChanged signal on success/error.
*/
- void setImapStatus( KMFolder* folder, const TQString& path, const TQCString& flags );
+ void setImaptqStatus( KMFolder* folder, const TQString& path, const TQCString& flags );
/**
* Set seen status on the server.
* Emits imapStatusChanged signal on success/error.
*/
- void setImapSeenStatus( KMFolder* folder, const TQString& path, bool seen );
+ void setImapSeentqStatus( KMFolder* folder, const TQString& path, bool seen );
/**
* The KIO-Slave died
@@ -400,16 +401,16 @@ namespace KMail {
return mCapabilities.tqcontains( capa ); }
/**
* Create an IMAP path for a parent folder and a foldername
* Parent and folder are separated with the delimiter of the account
* The path starts and ends with '/'
*/
- TQString createImapPath( FolderStorage* parent, const TQString& folderName );
+ TQString createImapPath( FolderStorage* tqparent, const TQString& folderName );
/**
* Create an IMAP path for a parent imapPath and a folderName
*/
- TQString createImapPath( const TQString& parent, const TQString& folderName );
+ TQString createImapPath( const TQString& tqparent, const TQString& folderName );
public slots:
@@ -509,8 +510,8 @@ namespace KMail {
/**
* Build KMMessageParts and DwBodyParts from the bodystructure-stream
*/
- void constructParts( TQDataStream & stream, int count, KMMessagePart* parentKMPart,
- DwBodyPart * parent, const DwMessage * dwmsg );
+ void constructParts( TQDataStream & stream, int count, KMMessagePart* tqparentKMPart,
+ DwBodyPart * tqparent, const DwMessage * dwmsg );
/** Migrate the prefix */
void migratePrefix();
@@ -590,13 +591,13 @@ namespace KMail {
/**
* Emitted when changeSubscription() failed.
- * @param errorMessage the error message that tqcontains the reason for the failure
+ * @param errorMessage the error message that contains the reason for the failure
*/
void subscriptionChangeFailed( const TQString &errorMessage );
/**
* Emitted upon completion of the job for setting the status for a group of UIDs,
* as a result of a setImapStatus call.
* On error, if the user chooses abort (not continue), cont is set to false.
*/
void imapStatusChanged( KMFolder*, const TQString& imapPath, bool cont );
@@ -400,16 +401,16 @@ namespace KMail {
return mCapabilities.tqcontains( capa ); }
/**
- * Create an IMAP path for a parent folder and a foldername
+ * Create an IMAP path for a tqparent folder and a foldername
* Parent and folder are separated with the delimiter of the account
* The path starts and ends with '/'
@@ -400,16 +401,16 @@ namespace KMail {
/**
- * Create an IMAP path for a parent imapPath and a folderName
+ * Create an IMAP path for a tqparent imapPath and a folderName
*/
@@ -590,13 +591,13 @@ namespace KMail {
/**
* Emitted upon completion of the job for setting the status for a group of UIDs,
- * as a result of a setImapStatus call.
+ * as a result of a setImaptqStatus call.
* On error, if the user chooses abort (not continue), cont is set to false.
*/